@@ -1,60 +1,60 @@
 from typing import List, Optional
 from ddd_objects.domain.entity import Entity, ExpiredEntity
 from .value_obj import (
-    KeyType,
-    GPUType,
-    InstanceTypeStatusCategory,
-    ZoneID,
-    DomainName,
-    InternetPayType,
-    ImageID,
-    Number,
-    InstanceTypeStatus,
-    PodStatus,
-    Output,
-    Info,
-    TimeInterval,
-    ServiceType,
-    Value,
-    Name,
-    Port,
-    BandWidth,
-    Subdomain,
     Data,
-    Key,
-    Price,
-    InstanceName,
-    RegionID,
-    Version,
-    Status,
-    InstanceID,
-    Path,
-    SecurityGroupID,
-    Weight,
-    NodeName,
-    NodeType,
-    Command,
-    Size,
-    Time,
-    NodeStatus,
-    Usage,
-    Endpoint,
-    Hostname,
-    DNSLine,
-    IP,
-    InstanceType,
-    Token,
-    ID,
+    Number,
     PayType,
-    DateTime,
-    Username,
-    IngressHost,
-    DNSType,
-    RecordID,
+    ID,
+    SecurityGroupID,
+    Size,
+    Price,
+    KeyType,
+    Subdomain,
+    NodeStatus,
+    Token,
+    NodeName,
+    BandWidth,
+    InstanceType,
+    RegionID,
     Type,
-    Password,
+    Name,
+    TimeInterval,
+    Version,
+    GPUType,
+    InternetPayType,
+    DomainName,
+    Endpoint,
+    IP,
+    Key,
+    RecordID,
+    Time,
+    Path,
+    Usage,
+    Username,
+    InstanceTypeStatusCategory,
+    InstanceID,
+    DNSType,
+    ServiceType,
+    Output,
+    NodeType,
+    Weight,
+    Hostname,
+    Info,
     Bool,
-    NodeLabel
+    DateTime,
+    Command,
+    NodeLabel,
+    InstanceTypeStatus,
+    DNSLine,
+    IngressHost,
+    Status,
+    Port,
+    Password,
+    ImageID,
+    ZoneID,
+    InstanceName,
+    PodStatus,
+    Value
 )
 
 class Condition(Entity):
@@ -630,4 +630,18 @@ class Service(ExpiredEntity):
         self.port_info=port_info
         self.age=age
         self._life_time=_life_time
+        super().__init__(_life_time)
+
+class PodContainer(ExpiredEntity):
+    def __init__(
+        self,
+        pod_name: Name,
+        init_container_info: Info,
+        container_info: Info,
+        _life_time: Number = Number(5)
+    ):
+        self.pod_name=pod_name
+        self.init_container_info=init_container_info
+        self.container_info=container_info
+        self._life_time=_life_time
         super().__init__(_life_time)
\ No newline at end of file
