@@ -1,3 +1,4 @@
+from shutil import disk_usage
 from typing import List
 from ddd_objects.infrastructure.converter import Converter
 from ..domain.entity import (
@@ -364,16 +365,16 @@ class NodeInfoConverter(Converter):
             security_group_id = [SecurityGroupID(m) for m in do.security_group_id],
             node_label = NodeLabel(do.node_label),
             cpu_number = Number(do.cpu_number),
-            cpu_usage = Usage(do.cpu_usage),
-            memory_size = Size(do.memory_size),
-            actual_memory_size = Size(do.actual_memory_size),
-            memory_usage = Size(do.memory_usage),
-            flow_in = Size(do.flow_in),
-            flow_out = Size(do.flow_out),
-            disk_size = Size(do.disk_size),
-            disk_usage = Usage(do.disk_usage),
-            io_in = Number(do.io_in),
-            io_out = Number(do.io_out),
+            cpu_usage = None if do.cpu_usage is None else Usage(do.cpu_usage),
+            memory_size = None if do.memory_size is None else Size(do.memory_size),
+            actual_memory_size = None if do.actual_memory_size is None else Size(do.actual_memory_size),
+            memory_usage = None if do.memory_usage is None else Size(do.memory_usage),
+            flow_in = None if do.flow_in is None else Size(do.flow_in),
+            flow_out = None if do.flow_out is None else Size(do.flow_out),
+            disk_size = None if do.disk_size is None else Size(do.disk_size),
+            disk_usage = None if do.disk_usage is None else Usage(do.disk_usage),
+            io_in = None if do.io_in is None else Number(do.io_in),
+            io_out = None if do.io_out is None else Number(do.io_out),
             gpu_type = GPUType(do.gpu_type),
             gpu_number = Number(do.gpu_number),
             instance_type_status = InstanceTypeStatus(do.instance_type_status),
